nx.ui.nx.Util - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.ui.nx.Util Class

Module: nx.ui

This is Util

## Constructor

### `nx.ui.nx.Util`

()

- Index
- Methods

## Item Index

### Methods

- capitalize
- deCamelCase
- getCssText
- getStyleProperty
- getStyleValue
- lowerCamelCase
- upperCamelCase

## Methods

### `capitalize`

(

- `inString`

)
String

Upper first word of a string.

#### Parameters:

- `inString` Object

#### Returns:

String:

### `deCamelCase`

(

- `inName`

)
| String | Void

Decode camel case to '-' model.

#### Parameters:

- `inName` Object

#### Returns:

| String | Void:

### `getCssText`

(

- `inStyles`

)
String

Get a string which is join by an style object.

#### Parameters:

- `inStyles` Object

#### Returns:

String:

### `getStyleProperty`

(

- `inName`
- `isLowerCase`

)

Get compatible css property.

#### Parameters:

- `inName` Object
- `isLowerCase` Object

#### Returns:

:

### `getStyleValue`

(

- `inName`
- `inValue`

)

Get real value of the style name.

#### Parameters:

- `inName` Object
- `inValue` Object

#### Returns:

:

### `lowerCamelCase`

(

- `inName`

)
String

Lower camel case.

#### Parameters:

- `inName` Object

#### Returns:

String:

### `upperCamelCase`

(

- `inName`

)
| String | Void

Upper camel case.

#### Parameters:

- `inName` Object

#### Returns:

| String | Void: